
 ![Logo Couleur West IT](https://couleurwest-it.com/static/images/ban)

# Dreamtools

**Librairies de fonctions aide au développement**

Vous pouvez télécharger depuis notre dépôt Github:  [Dreamtools](https://github.com/couleurwest/dreamgeeker-tools/)

[Lire la documentation](https://couleurwest-it.com/dreamtools) | [Télécharger documentation](https://couleurwest-it.com/dreamtools)

## Paquets dépendants

**Environnement Python 3.8**

* cerberus
* pyaml
* pillow 
* pycrypt (uniquement sous Linux)
* requests

## Génération documentation

* html : sphinx
* pdf : rinohtype

## Couleur West IT
[Conception & Réalisation de solutions numériques adaptées](https://couleurwest-it.com)

*Accompagement au changement*

### Un conseil, un avis, une expertises 
[Ecrivez-nous par mail](contact@couleurwest-it.com) | [Par Telegram](https://t.me/dreamgeeker)